@@ -1,4 +1,4 @@
-package Pcore::Nginx v0.1.1;
+package Pcore::Nginx v0.2.0;
 
 use Pcore qw[-class];
 
@@ -10,7 +10,7 @@ __END__
 
 =head1 NAME
 
-Pcore::Nginx
+Pcore::Nginx - Pcore nginx application
 
 =head1 SYNOPSIS
 
